# ufs2arco
[![PyPI version](https://img.shields.io/pypi/v/ufs2arco.svg)](https://pypi.org/project/ufs2arco/)
![OS Support](https://img.shields.io/badge/OS-Linux%20%7C%20macOS-blue?)
![Python](https://img.shields.io/badge/Python-3.9%20|%203.10%20|%203.11%20|%203.12-blue?logo=python&logoColor=white)
[![Documentation Status](https://readthedocs.org/projects/ufs2arco/badge/?version=latest)](https://ufs2arco.readthedocs.io/en/latest/?badge=latest)

Tools for converting Unified Forecast System (UFS) output to Analysis Ready, Cloud Optimized (ARCO) format

## Installation


### Installation from pip

```bash
pip install ufs2arco
```

### Installation from GitHub

To obtain the latest development version, clone
[the repository](https://github.com/NOAA-PSL/ufs2arco>)
and install it as follows

```bash
git clone https://github.com/NOAA-PSL/ufs2arco.git
cd ufs2arco
pip install -e .
```
